summaryrefslogtreecommitdiff
path: root/lib
diff options
context:
space:
mode:
authorjbj <devnull@localhost>2005-03-17 17:12:26 +0000
committerjbj <devnull@localhost>2005-03-17 17:12:26 +0000
commit4c63745fe818b616feb3395c953ac1833d65b551 (patch)
tree6e537b4309b791206f097f30ad01e1068b9c9e4c /lib
parenta839baba3fb30d3d37c25310358747319bd50692 (diff)
downloadlibrpm-tizen-4c63745fe818b616feb3395c953ac1833d65b551.tar.gz
librpm-tizen-4c63745fe818b616feb3395c953ac1833d65b551.tar.bz2
librpm-tizen-4c63745fe818b616feb3395c953ac1833d65b551.zip
Add tagType().
CVS patchset: 7818 CVS date: 2005/03/17 17:12:26
Diffstat (limited to 'lib')
-rw-r--r--lib/rpmlib.h16
1 files changed, 12 insertions, 4 deletions
diff --git a/lib/rpmlib.h b/lib/rpmlib.h
index 0a2447092..006721d86 100644
--- a/lib/rpmlib.h
+++ b/lib/rpmlib.h
@@ -1058,9 +1058,17 @@ void rpmShowRpmlibProvides(FILE * fp)
/*@}*/
/**
* Return name of tag from value.
* @param tag tag value
- * @return name of tag
+ * @return tag data type, RPM_NULL_TYPE on not found.
+ */
+int tagType(int tag)
+ /*@*/;
+
+/**
+ * Return tag name from value.
+ * @param tag tag value
+ * @return tag name, "(unknown)" on not found
*/
/*@-redecl@*/
/*@observer@*/ extern const char *const tagName(int tag)
@@ -1068,9 +1076,9 @@ void rpmShowRpmlibProvides(FILE * fp)
/*@=redecl@*/
/**
- * Return value of tag from name.
+ * Return tag value from name.
* @param tagstr name of tag
- * @return tag value
+ * @return tag value, -1 on not found
*/
int tagValue(const char * tagstr)
/*@*/;
@@ -1058,9 +1058,17 @@ void rpmShowRpmlibProvides(FILE * fp)
/*@}*/
/**
- * Return name of tag from value.
+ * Return tag data type from value.
* @param tag tag value